@@ -2,7 +2,7 @@ from platonic.sqs.queue.errors import (
     SQSMessageDoesNotExist,
     SQSQueueDoesNotExist,
 )
-from platonic.sqs.queue.input import SQSInputQueue
 from platonic.sqs.queue.message import SQSMessage
-from platonic.sqs.queue.output import SQSOutputQueue
+from platonic.sqs.queue.receiver import SQSReceiver
+from platonic.sqs.queue.sender import SQSSender
 from platonic.sqs.queue.types import InternalType, ValueType
